@@ -25,7 +25,7 @@ use strict;
 use warnings;
 
 use WWW::GoodData::Agent;
-use JSON::XS;
+use JSON;
 use URI;
 
 our $root = new URI ('https://secure.gooddata.com/gdc');
@@ -65,7 +65,6 @@ sub new
 	bless $self, $class;
 	$self->{agent} ||= new WWW::GoodData::Agent ($root);
 	$self->{retries} ||= 3600;
-	$self->{agent}->{error_callback} = \&error_callback;
 	return $self;
 }
 
@@ -369,12 +368,18 @@ sub export_report
 			report => $self->compute_report ($report) }}
 	);
 
+	# This is for new release, where location is finally set correctly;
+	$result = $result->{uri} if ref $result eq 'HASH';
+
 	# Trigger the export
 	my $exported = $self->poll (
 		sub { $self->{agent}->get ($result) },
-		sub { shift->{raw} ne 'null' }
+		sub { $_[0] and exists $_[0]->{raw} and $_[0]->{raw} ne 'null' }
 	) or die 'Timed out waiting for report to export';
 
+	# Follow the link
+	$exported = $self->{agent}->get ($exported->{uri}) if exists $exported->{uri};
+
 	# Gotten the correctly coded result?
 	return $exported->{raw} if $exported->{type} eq {
 		png => 'image/png',
